@@ -6,12 +6,12 @@
 #include <Rdefines.h>
 #include <Rinternals.h>
 
-static void eval_vf (pomp_vectorfield_map *vf,
-		     double *f, 
-		     double *x, double *times, double *params, 
-		     int *ndim,
-		     int *stateindex, int *parindex, int *covindex,
-		     double *time_table, double *covar_table)
+static void eval_skel (pomp_vectorfield_map *vf,
+		       double *f, 
+		       double *x, double *times, double *params, 
+		       int *ndim,
+		       int *stateindex, int *parindex, int *covindex,
+		       double *time_table, double *covar_table)
 {
   double t, *xp, *pp, *fp;
   int nvar = ndim[0];
@@ -48,7 +48,7 @@ static void eval_vf (pomp_vectorfield_map *vf,
   }
 }
 
-// these global objects will pass the needed information to the user-defined function (see 'default_vf_fn')
+// these global objects will pass the needed information to the user-defined function (see 'default_skel_fn')
 // each of these is allocated once, globally, and refilled many times
 static SEXP _pomp_skel_Xvec;	// state variable vector
 static SEXP _pomp_skel_Pvec;	// parameter vector
@@ -71,9 +71,9 @@ static SEXP _pomp_skel_fcall;	// function call
 // this is the vectorfield that is evaluated when the user supplies an R function
 // (and not a native routine)
 // Note that stateindex, parindex, covindex are ignored.
-static void default_vf_fn (double *f, double *x, double *p, 
-			   int *stateindex, int *parindex, int *covindex, 
-			   int covdim, double *covar, double t)
+static void default_skel_fn (double *f, double *x, double *p, 
+			     int *stateindex, int *parindex, int *covindex, 
+			     int covdim, double *covar, double t)
 {
   int nprotect = 0;
   int k;
@@ -88,6 +88,10 @@ static void default_vf_fn (double *f, double *x, double *p,
   xp = REAL(TIME);
   xp[0] = t;
   PROTECT(ans = eval(FCALL,RHO)); nprotect++; // evaluate the call
+  if (LENGTH(ans)!=NVAR) {
+    UNPROTECT(nprotect);
+    error("skeleton error: user 'skeleton' must return a vector of length %d",NVAR);
+  }
   xp = REAL(AS_NUMERIC(ans));
   for (k = 0; k < NVAR; k++) f[k] = xp[k];
   UNPROTECT(nprotect);
@@ -100,12 +104,14 @@ SEXP do_skeleton (SEXP object, SEXP x, SEXP t, SEXP params)
   int fdim[3], ndim[6];
   int use_native;
   int nstates, nparams, ncovars;
+  double *xp;
   SEXP dimP, dimX, fn, F;
   SEXP tcovar, covar;
   SEXP statenames, paramnames, covarnames;
   SEXP sindex, pindex, cindex;
   SEXP Xnames, Pnames, Cnames;
   pomp_vectorfield_map *ff = NULL;
+  int k;
 
   ntimes = LENGTH(t);
 
@@ -158,12 +164,14 @@ SEXP do_skeleton (SEXP object, SEXP x, SEXP t, SEXP params)
   if (use_native) {
     ff = (pomp_vectorfield_map *) R_ExternalPtrAddr(fn);
   } else {		    // else construct a call to the R function
-    ff = (pomp_vectorfield_map *) default_vf_fn;
+    ff = (pomp_vectorfield_map *) default_skel_fn;
     PROTECT(RHO = (CLOENV(fn))); nprotect++;
     NVAR = nvars;			// for internal use
     NPAR = npars;			// for internal use
     PROTECT(TIME = NEW_NUMERIC(1)); nprotect++;	// for internal use
     PROTECT(XVEC = NEW_NUMERIC(nvars)); nprotect++; // for internal use
+    xp = REAL(XVEC);
+    for (k = 0; k < nvars; k++) xp[k] = 0.0;
     PROTECT(PVEC = NEW_NUMERIC(npars)); nprotect++; // for internal use
     PROTECT(CVEC = NEW_NUMERIC(covdim)); nprotect++; // for internal use
     SET_NAMES(XVEC,Xnames); // make sure the names attribute is copied
@@ -185,6 +193,9 @@ SEXP do_skeleton (SEXP object, SEXP x, SEXP t, SEXP params)
   fdim[0] = nvars; fdim[1] = nreps; fdim[2] = ntimes;
   PROTECT(F = makearray(3,fdim)); nprotect++; 
   setrownames(F,Xnames,3);
+  xp = REAL(F);
+  for (k = 0; k < nvars*nreps*ntimes; k++) xp[k] = 0.0;
+
   if (nstates > 0) {
     PROTECT(sindex = MATCHROWNAMES(x,statenames)); nprotect++;
   } else {
@@ -200,11 +211,13 @@ SEXP do_skeleton (SEXP object, SEXP x, SEXP t, SEXP params)
   } else {
     PROTECT(cindex = NEW_INTEGER(0)); nprotect++;
   }
+
   ndim[0] = nvars; ndim[1] = npars; ndim[2] = nreps; ndim[3] = ntimes; 
   ndim[4] = covlen; ndim[5] = covdim;
-  eval_vf(ff,REAL(F),REAL(x),REAL(t),REAL(params),
-	  ndim,INTEGER(sindex),INTEGER(pindex),INTEGER(cindex),
-	  REAL(tcovar),REAL(covar));
+
+  eval_skel(ff,REAL(F),REAL(x),REAL(t),REAL(params),
+	    ndim,INTEGER(sindex),INTEGER(pindex),INTEGER(cindex),
+	    REAL(tcovar),REAL(covar));
 
   UNPROTECT(nprotect);
   return F;
